@@ -1,4 +1,4 @@
-__version__ = '0.0.9'
+__version__ = '0.0.10'
 
 
 import win32api
@@ -11,9 +11,11 @@ import cv2
 import numpy as np
 import re
 import os
+import math
 
 from ctypes import windll
 from threading import Thread
+from scipy.optimize import fsolve
 
 from .dl_script import load_onnx, build_preprocess, build_postprocess
 
