@@ -15,7 +15,8 @@ ddata = {
     '确认退出战斗': (433, 344, (255, 229, 71)),
     '关闭竞技大厅': (914, 43, (255, 231, 120)),
     '打气球开始': (500, 520, (217, 91, 21)),
-    '轮到自己回合': (494, 169, (255, 190, 112))
+    '轮到自己回合': (494, 169, (255, 190, 112)),
+    '弹球开始': (400, 509, (0, 88, 58))
 }
 
 if __name__ == '__main__':
