@@ -4,7 +4,7 @@ import ddtank
 keycode_dict = {
     "back": 0x08,
     "tab": 0x09,
-    "return": 0x0D,
+    "enter": 0x0D,
     "shift": 0x10,
     "control": 0x11,
     "menu": 0x12,
@@ -62,6 +62,7 @@ keycode_dict = {
     "rmenu": 0XA5
 }
 
+
 def get_keycode(key: str) -> int:
     """
     获取按键的键值
@@ -75,6 +76,7 @@ def get_keycode(key: str) -> int:
     else:
         return -1
 
+
 class Status:
     def __init__(self, info: Union[dict, int]):
         if type(info) == dict:
@@ -142,6 +144,56 @@ class Status:
         else:
             ddtank.time.sleep(period / 1000)
 
+    @staticmethod
+    def aim(angle: int, wind: float, distance_x: float, distance_y: float) -> float:
+        """
+        根据给定条件，计算击中目标所需的力度
+        :param angle: 角度
+        :param wind: 风力，顺风为正，逆风为负
+        :param distance_x: 横向距离，单位为屏距
+        :param distance_y: 纵向距离，单位为屏距
+        :return: 拟合得到的力度结果
+        """
+        if angle > 90:
+            angle = 180 - angle
+        r, w, g = [0.90289815, 6.33592869, -184.11666458]
+        shot_angel = angle
+        position_angel = ddtank.math.atan(distance_y / distance_x)
+        position_angel = position_angel * 180 / ddtank.math.pi
+        x_angel = shot_angel - position_angel
+        y_angel = 90 - shot_angel + position_angel
+        x_angel = x_angel * ddtank.math.pi / 180
+        y_angel = y_angel * ddtank.math.pi / 180
+        position_angel = position_angel * ddtank.math.pi / 180
+
+        def solve(F):
+            vx = ddtank.math.cos(x_angel) * F
+            vy = ddtank.math.cos(y_angel) * F
+            fx = ddtank.math.cos(position_angel) * w * wind + ddtank.math.sin(position_angel) * g
+            fy = -ddtank.math.sin(position_angel) * w * wind + ddtank.math.cos(position_angel) * g
+
+            def computePosition(v0, f, r, t):
+                temp = f - r * v0
+                ert = ddtank.np.power(ddtank.math.e, -r * t)
+                right = temp * ert + f * r * t - temp
+                return right / (r * r)
+
+            def getTime(v0):
+                solve_l = lambda t1: computePosition(v0, fy, r, t1)
+                time = ddtank.fsolve(solve_l, [2])
+                assert time[0] != 0
+                return time[0]
+
+            t = getTime(vy)
+            return computePosition(vx, fx, r, t) - ddtank.math.sqrt(distance_x ** 2 + distance_y ** 2)
+
+        f = ddtank.fsolve(solve, [100])
+        if f[0] > 100:
+            return 100.0
+        elif f[0] < 0:
+            return 0.0
+        return f[0]
+
     def activate(self, period: int = 100):
         """
         激活角色游戏窗口
@@ -214,7 +266,7 @@ class Status:
         if save_capture:
             if not ddtank.os.path.exists('./capture'):
                 ddtank.os.mkdir('./capture')
-            ddtank.cv2.imwrite('./capture/capture.png', img)
+            ddtank.cv2.imwrite(f'./capture/{self.hwnd}.png', img)
         return img
 
     def ocr(self, model: str) -> Union[int, float, str, type(None)]:
@@ -308,7 +360,8 @@ class Status:
             return True
         return False
 
-    def click_pixel_back(self, coordinate_x: int, coordinate_y: int, pixel_x: int, pixel_y: int, pixel: tuple, period: int = 500) -> bool:
+    def click_pixel_back(self, coordinate_x: int, coordinate_y: int, pixel_x: int, pixel_y: int, pixel: tuple,
+                         period: int = 500) -> bool:
         """
         对角色模拟单击操作后等待一段时间，如果指定位置像素不符合条件时将继续模拟单击操作直到符合条件
         :param coordinate_x: 单击点的x坐标
@@ -421,9 +474,11 @@ class Status:
         white_box = (-1, -1, -1)
         blue_point = (-1, -1)
 
-        small_map_left_x = ddtank.np.argwhere(ddtank.np.all(status_img[1, 750:] == [160, 160, 160], axis=-1))[0, 0] + 742
+        small_map_left_x = ddtank.np.argwhere(ddtank.np.all(status_img[1, 750:] == [160, 160, 160], axis=-1))[
+                               0, 0] + 742
 
-        img_res = ddtank.np.where(ddtank.np.any(status_img[24:120, small_map_left_x:998] != [153, 153, 153], axis=-1), 0, 255).astype('uint8')
+        img_res = ddtank.np.where(ddtank.np.any(status_img[24:120, small_map_left_x:998] != [153, 153, 153], axis=-1),
+                                  0, 255).astype('uint8')
         contours, hierarchy = ddtank.cv2.findContours(img_res, ddtank.cv2.RETR_TREE, ddtank.cv2.CHAIN_APPROX_SIMPLE)
         for cnt in contours:
             x, y, w, h = ddtank.cv2.boundingRect(cnt)
@@ -431,7 +486,8 @@ class Status:
                 white_box = (x, y, w / 10)
                 break
 
-        img_res = ddtank.np.where(ddtank.np.any(status_img[24:120, small_map_left_x:998] != [204, 51, 0], axis=-1), 0, 255).astype('uint8')
+        img_res = ddtank.np.where(ddtank.np.any(status_img[24:120, small_map_left_x:998] != [204, 51, 0], axis=-1), 0,
+                                  255).astype('uint8')
         contours, hierarchy = ddtank.cv2.findContours(img_res, ddtank.cv2.RETR_TREE, ddtank.cv2.CHAIN_APPROX_SIMPLE)
         for cnt in contours:
             x, y, w, h = ddtank.cv2.boundingRect(cnt)
@@ -480,8 +536,3 @@ class Status:
             self.press('D', period=move_period)
             if reverse_face:
                 self.press('A')
-
-
-
-
-
